/* -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
#ifndef _GSM_E_DATE_H_
#define _GSM_E_DATE_H_

#include <time.h>
#include <glib.h>

G_BEGIN_DECLS

char *
procman_format_date_for_display(time_t d);

G_END_DECLS

#endif /* _GSM_E_DATE_H_ */
